<a id="mypy-boto3-glue"></a>

# mypy-boto3-glue

[![PyPI - mypy-boto3-glue](https://img.shields.io/pypi/v/mypy-boto3-glue.svg?color=blue)](https://pypi.org/project/mypy-boto3-glue)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-glue.svg?color=blue)](https://pypi.org/project/mypy-boto3-glue)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-glue?color=blue)](https://pypistats.org/packages/mypy-boto3-glue)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Glue 1.18.46](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/glue.html#Glue)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.3.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-glue docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_glue/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-glue](#mypy-boto3-glue)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Glue` service.

```bash
python -m pip install boto3-stubs[glue]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[glue]` in your environment:
  `python -m pip install 'boto3-stubs[glue]'`

Both type checking and auto-complete should work for `Glue` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[glue]` in your environment:
  `python -m pip install 'boto3-stubs[glue]'`

Both type checking and auto-complete should work for `Glue` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[glue]` in your environment:
  `python -m pip install 'boto3-stubs[glue]'`
- Run `mypy` as usual

Type checking should work for `Glue` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[glue]` in your environment:
  `python -m pip install 'boto3-stubs[glue]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Glue` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`GlueClient` provides annotations for `boto3.client("glue")`.

```python
import boto3

from mypy_boto3_glue import GlueClient

client: GlueClient = boto3.client("glue")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: GlueClient = session.client("glue")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_glue.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_glue import GlueClient
from mypy_boto3_glue.paginator import (
    GetClassifiersPaginator,
    GetConnectionsPaginator,
    GetCrawlerMetricsPaginator,
    GetCrawlersPaginator,
    GetDatabasesPaginator,
    GetDevEndpointsPaginator,
    GetJobRunsPaginator,
    GetJobsPaginator,
    GetPartitionIndexesPaginator,
    GetPartitionsPaginator,
    GetResourcePoliciesPaginator,
    GetSecurityConfigurationsPaginator,
    GetTableVersionsPaginator,
    GetTablesPaginator,
    GetTriggersPaginator,
    GetUserDefinedFunctionsPaginator,
    ListRegistriesPaginator,
    ListSchemaVersionsPaginator,
    ListSchemasPaginator,
)

client: GlueClient = boto3.client("glue")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_classifiers_paginator: GetClassifiersPaginator = client.get_paginator("get_classifiers")
get_connections_paginator: GetConnectionsPaginator = client.get_paginator("get_connections")
get_crawler_metrics_paginator: GetCrawlerMetricsPaginator = client.get_paginator("get_crawler_metrics")
get_crawlers_paginator: GetCrawlersPaginator = client.get_paginator("get_crawlers")
get_databases_paginator: GetDatabasesPaginator = client.get_paginator("get_databases")
get_dev_endpoints_paginator: GetDevEndpointsPaginator = client.get_paginator("get_dev_endpoints")
get_job_runs_paginator: GetJobRunsPaginator = client.get_paginator("get_job_runs")
get_jobs_paginator: GetJobsPaginator = client.get_paginator("get_jobs")
get_partition_indexes_paginator: GetPartitionIndexesPaginator = client.get_paginator("get_partition_indexes")
get_partitions_paginator: GetPartitionsPaginator = client.get_paginator("get_partitions")
get_resource_policies_paginator: GetResourcePoliciesPaginator = client.get_paginator("get_resource_policies")
get_security_configurations_paginator: GetSecurityConfigurationsPaginator = client.get_paginator("get_security_configurations")
get_table_versions_paginator: GetTableVersionsPaginator = client.get_paginator("get_table_versions")
get_tables_paginator: GetTablesPaginator = client.get_paginator("get_tables")
get_triggers_paginator: GetTriggersPaginator = client.get_paginator("get_triggers")
get_user_defined_functions_paginator: GetUserDefinedFunctionsPaginator = client.get_paginator("get_user_defined_functions")
list_registries_paginator: ListRegistriesPaginator = client.get_paginator("list_registries")
list_schema_versions_paginator: ListSchemaVersionsPaginator = client.get_paginator("list_schema_versions")
list_schemas_paginator: ListSchemasPaginator = client.get_paginator("list_schemas")
```

<a id="literals"></a>

### Literals

`mypy_boto3_glue.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_glue.literals import (
    BackfillErrorCodeType,
    BlueprintRunStateType,
    BlueprintStatusType,
    CatalogEncryptionModeType,
    CloudWatchEncryptionModeType,
    ColumnStatisticsTypeType,
    ComparatorType,
    CompatibilityType,
    ConnectionPropertyKeyType,
    ConnectionTypeType,
    CrawlStateType,
    CrawlerLineageSettingsType,
    CrawlerStateType,
    CsvHeaderOptionType,
    DataFormatType,
    DeleteBehaviorType,
    EnableHybridValuesType,
    ExistConditionType,
    GetClassifiersPaginatorName,
    GetConnectionsPaginatorName,
    GetCrawlerMetricsPaginatorName,
    GetCrawlersPaginatorName,
    GetDatabasesPaginatorName,
    GetDevEndpointsPaginatorName,
    GetJobRunsPaginatorName,
    GetJobsPaginatorName,
    GetPartitionIndexesPaginatorName,
    GetPartitionsPaginatorName,
    GetResourcePoliciesPaginatorName,
    GetSecurityConfigurationsPaginatorName,
    GetTableVersionsPaginatorName,
    GetTablesPaginatorName,
    GetTriggersPaginatorName,
    GetUserDefinedFunctionsPaginatorName,
    JobBookmarksEncryptionModeType,
    JobRunStateType,
    LanguageType,
    LastCrawlStatusType,
    ListRegistriesPaginatorName,
    ListSchemaVersionsPaginatorName,
    ListSchemasPaginatorName,
    LogicalOperatorType,
    LogicalType,
    MLUserDataEncryptionModeStringType,
    NodeTypeType,
    PartitionIndexStatusType,
    PermissionType,
    PrincipalTypeType,
    RecrawlBehaviorType,
    RegistryStatusType,
    ResourceShareTypeType,
    ResourceTypeType,
    S3EncryptionModeType,
    ScheduleStateType,
    SchemaDiffTypeType,
    SchemaStatusType,
    SchemaVersionStatusType,
    SortDirectionTypeType,
    SortType,
    TaskRunSortColumnTypeType,
    TaskStatusTypeType,
    TaskTypeType,
    TransformSortColumnTypeType,
    TransformStatusTypeType,
    TransformTypeType,
    TriggerStateType,
    TriggerTypeType,
    UpdateBehaviorType,
    WorkerTypeType,
    WorkflowRunStatusType,
    ServiceName,
)

def check_value(value: BackfillErrorCodeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_glue.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_glue.type_defs import (
    ActionTypeDef,
    BackfillErrorTypeDef,
    BatchCreatePartitionRequestRequestTypeDef,
    BatchCreatePartitionResponseTypeDef,
    BatchDeleteConnectionRequestRequestTypeDef,
    BatchDeleteConnectionResponseTypeDef,
    BatchDeletePartitionRequestRequestTypeDef,
    BatchDeletePartitionResponseTypeDef,
    BatchDeleteTableRequestRequestTypeDef,
    BatchDeleteTableResponseTypeDef,
    BatchDeleteTableVersionRequestRequestTypeDef,
    BatchDeleteTableVersionResponseTypeDef,
    BatchGetBlueprintsRequestRequestTypeDef,
    BatchGetBlueprintsResponseTypeDef,
    BatchGetCrawlersRequestRequestTypeDef,
    BatchGetCrawlersResponseTypeDef,
    BatchGetDevEndpointsRequestRequestTypeDef,
    BatchGetDevEndpointsResponseTypeDef,
    BatchGetJobsRequestRequestTypeDef,
    BatchGetJobsResponseTypeDef,
    BatchGetPartitionRequestRequestTypeDef,
    BatchGetPartitionResponseTypeDef,
    BatchGetTriggersRequestRequestTypeDef,
    BatchGetTriggersResponseTypeDef,
    BatchGetWorkflowsRequestRequestTypeDef,
    BatchGetWorkflowsResponseTypeDef,
    BatchStopJobRunErrorTypeDef,
    BatchStopJobRunRequestRequestTypeDef,
    BatchStopJobRunResponseTypeDef,
    BatchStopJobRunSuccessfulSubmissionTypeDef,
    BatchUpdatePartitionFailureEntryTypeDef,
    BatchUpdatePartitionRequestEntryTypeDef,
    BatchUpdatePartitionRequestRequestTypeDef,
    BatchUpdatePartitionResponseTypeDef,
    BinaryColumnStatisticsDataTypeDef,
    BlueprintDetailsTypeDef,
    BlueprintRunTypeDef,
    BlueprintTypeDef,
    BooleanColumnStatisticsDataTypeDef,
    CancelMLTaskRunRequestRequestTypeDef,
    CancelMLTaskRunResponseTypeDef,
    CatalogEntryTypeDef,
    CatalogImportStatusTypeDef,
    CatalogTargetTypeDef,
    CheckSchemaVersionValidityInputRequestTypeDef,
    CheckSchemaVersionValidityResponseTypeDef,
    ClassifierTypeDef,
    CloudWatchEncryptionTypeDef,
    CodeGenEdgeTypeDef,
    CodeGenNodeArgTypeDef,
    CodeGenNodeTypeDef,
    ColumnErrorTypeDef,
    ColumnImportanceTypeDef,
    ColumnStatisticsDataTypeDef,
    ColumnStatisticsErrorTypeDef,
    ColumnStatisticsTypeDef,
    ColumnTypeDef,
    ConditionTypeDef,
    ConfusionMatrixTypeDef,
    ConnectionInputTypeDef,
    ConnectionPasswordEncryptionTypeDef,
    ConnectionTypeDef,
    ConnectionsListTypeDef,
    CrawlTypeDef,
    CrawlerMetricsTypeDef,
    CrawlerNodeDetailsTypeDef,
    CrawlerTargetsTypeDef,
    CrawlerTypeDef,
    CreateBlueprintRequestRequestTypeDef,
    CreateBlueprintResponseTypeDef,
    CreateClassifierRequestRequestTypeDef,
    CreateConnectionRequestRequestTypeDef,
    CreateCrawlerRequestRequestTypeDef,
    CreateCsvClassifierRequestTypeDef,
    CreateDatabaseRequestRequestTypeDef,
    CreateDevEndpointRequestRequestTypeDef,
    CreateDevEndpointResponseTypeDef,
    CreateGrokClassifierRequestTypeDef,
    CreateJobRequestRequestTypeDef,
    CreateJobResponseTypeDef,
    CreateJsonClassifierRequestTypeDef,
    CreateMLTransformRequestRequestTypeDef,
    CreateMLTransformResponseTypeDef,
    CreatePartitionIndexRequestRequestTypeDef,
    CreatePartitionRequestRequestTypeDef,
    CreateRegistryInputRequestTypeDef,
    CreateRegistryResponseTypeDef,
    CreateSchemaInputRequestTypeDef,
    CreateSchemaResponseTypeDef,
    CreateScriptRequestRequestTypeDef,
    CreateScriptResponseTypeDef,
    CreateSecurityConfigurationRequestRequestTypeDef,
    CreateSecurityConfigurationResponseTypeDef,
    CreateTableRequestRequestTypeDef,
    CreateTriggerRequestRequestTypeDef,
    CreateTriggerResponseTypeDef,
    CreateUserDefinedFunctionRequestRequestTypeDef,
    CreateWorkflowRequestRequestTypeDef,
    CreateWorkflowResponseTypeDef,
    CreateXMLClassifierRequestTypeDef,
    CsvClassifierTypeDef,
    DataCatalogEncryptionSettingsTypeDef,
    DataLakePrincipalTypeDef,
    DatabaseIdentifierTypeDef,
    DatabaseInputTypeDef,
    DatabaseTypeDef,
    DateColumnStatisticsDataTypeDef,
    DecimalColumnStatisticsDataTypeDef,
    DecimalNumberTypeDef,
    DeleteBlueprintRequestRequestTypeDef,
    DeleteBlueprintResponseTypeDef,
    DeleteClassifierRequestRequestTypeDef,
    DeleteColumnStatisticsForPartitionRequestRequestTypeDef,
    DeleteColumnStatisticsForTableRequestRequestTypeDef,
    DeleteConnectionRequestRequestTypeDef,
    DeleteCrawlerRequestRequestTypeDef,
    DeleteDatabaseRequestRequestTypeDef,
    DeleteDevEndpointRequestRequestTypeDef,
    DeleteJobRequestRequestTypeDef,
    DeleteJobResponseTypeDef,
    DeleteMLTransformRequestRequestTypeDef,
    DeleteMLTransformResponseTypeDef,
    DeletePartitionIndexRequestRequestTypeDef,
    DeletePartitionRequestRequestTypeDef,
    DeleteRegistryInputRequestTypeDef,
    DeleteRegistryResponseTypeDef,
    DeleteResourcePolicyRequestRequestTypeDef,
    DeleteSchemaInputRequestTypeDef,
    DeleteSchemaResponseTypeDef,
    DeleteSchemaVersionsInputRequestTypeDef,
    DeleteSchemaVersionsResponseTypeDef,
    DeleteSecurityConfigurationRequestRequestTypeDef,
    DeleteTableRequestRequestTypeDef,
    DeleteTableVersionRequestRequestTypeDef,
    DeleteTriggerRequestRequestTypeDef,
    DeleteTriggerResponseTypeDef,
    DeleteUserDefinedFunctionRequestRequestTypeDef,
    DeleteWorkflowRequestRequestTypeDef,
    DeleteWorkflowResponseTypeDef,
    DevEndpointCustomLibrariesTypeDef,
    DevEndpointTypeDef,
    DoubleColumnStatisticsDataTypeDef,
    DynamoDBTargetTypeDef,
    EdgeTypeDef,
    EncryptionAtRestTypeDef,
    EncryptionConfigurationTypeDef,
    ErrorDetailTypeDef,
    ErrorDetailsTypeDef,
    EvaluationMetricsTypeDef,
    EventBatchingConditionTypeDef,
    ExecutionPropertyTypeDef,
    ExportLabelsTaskRunPropertiesTypeDef,
    FindMatchesMetricsTypeDef,
    FindMatchesParametersTypeDef,
    FindMatchesTaskRunPropertiesTypeDef,
    GetBlueprintRequestRequestTypeDef,
    GetBlueprintResponseTypeDef,
    GetBlueprintRunRequestRequestTypeDef,
    GetBlueprintRunResponseTypeDef,
    GetBlueprintRunsRequestRequestTypeDef,
    GetBlueprintRunsResponseTypeDef,
    GetCatalogImportStatusRequestRequestTypeDef,
    GetCatalogImportStatusResponseTypeDef,
    GetClassifierRequestRequestTypeDef,
    GetClassifierResponseTypeDef,
    GetClassifiersRequestRequestTypeDef,
    GetClassifiersResponseTypeDef,
    GetColumnStatisticsForPartitionRequestRequestTypeDef,
    GetColumnStatisticsForPartitionResponseTypeDef,
    GetColumnStatisticsForTableRequestRequestTypeDef,
    GetColumnStatisticsForTableResponseTypeDef,
    GetConnectionRequestRequestTypeDef,
    GetConnectionResponseTypeDef,
    GetConnectionsFilterTypeDef,
    GetConnectionsRequestRequestTypeDef,
    GetConnectionsResponseTypeDef,
    GetCrawlerMetricsRequestRequestTypeDef,
    GetCrawlerMetricsResponseTypeDef,
    GetCrawlerRequestRequestTypeDef,
    GetCrawlerResponseTypeDef,
    GetCrawlersRequestRequestTypeDef,
    GetCrawlersResponseTypeDef,
    GetDataCatalogEncryptionSettingsRequestRequestTypeDef,
    GetDataCatalogEncryptionSettingsResponseTypeDef,
    GetDatabaseRequestRequestTypeDef,
    GetDatabaseResponseTypeDef,
    GetDatabasesRequestRequestTypeDef,
    GetDatabasesResponseTypeDef,
    GetDataflowGraphRequestRequestTypeDef,
    GetDataflowGraphResponseTypeDef,
    GetDevEndpointRequestRequestTypeDef,
    GetDevEndpointResponseTypeDef,
    GetDevEndpointsRequestRequestTypeDef,
    GetDevEndpointsResponseTypeDef,
    GetJobBookmarkRequestRequestTypeDef,
    GetJobBookmarkResponseTypeDef,
    GetJobRequestRequestTypeDef,
    GetJobResponseTypeDef,
    GetJobRunRequestRequestTypeDef,
    GetJobRunResponseTypeDef,
    GetJobRunsRequestRequestTypeDef,
    GetJobRunsResponseTypeDef,
    GetJobsRequestRequestTypeDef,
    GetJobsResponseTypeDef,
    GetMLTaskRunRequestRequestTypeDef,
    GetMLTaskRunResponseTypeDef,
    GetMLTaskRunsRequestRequestTypeDef,
    GetMLTaskRunsResponseTypeDef,
    GetMLTransformRequestRequestTypeDef,
    GetMLTransformResponseTypeDef,
    GetMLTransformsRequestRequestTypeDef,
    GetMLTransformsResponseTypeDef,
    GetMappingRequestRequestTypeDef,
    GetMappingResponseTypeDef,
    GetPartitionIndexesRequestRequestTypeDef,
    GetPartitionIndexesResponseTypeDef,
    GetPartitionRequestRequestTypeDef,
    GetPartitionResponseTypeDef,
    GetPartitionsRequestRequestTypeDef,
    GetPartitionsResponseTypeDef,
    GetPlanRequestRequestTypeDef,
    GetPlanResponseTypeDef,
    GetRegistryInputRequestTypeDef,
    GetRegistryResponseTypeDef,
    GetResourcePoliciesRequestRequestTypeDef,
    GetResourcePoliciesResponseTypeDef,
    GetResourcePolicyRequestRequestTypeDef,
    GetResourcePolicyResponseTypeDef,
    GetSchemaByDefinitionInputRequestTypeDef,
    GetSchemaByDefinitionResponseTypeDef,
    GetSchemaInputRequestTypeDef,
    GetSchemaResponseTypeDef,
    GetSchemaVersionInputRequestTypeDef,
    GetSchemaVersionResponseTypeDef,
    GetSchemaVersionsDiffInputRequestTypeDef,
    GetSchemaVersionsDiffResponseTypeDef,
    GetSecurityConfigurationRequestRequestTypeDef,
    GetSecurityConfigurationResponseTypeDef,
    GetSecurityConfigurationsRequestRequestTypeDef,
    GetSecurityConfigurationsResponseTypeDef,
    GetTableRequestRequestTypeDef,
    GetTableResponseTypeDef,
    GetTableVersionRequestRequestTypeDef,
    GetTableVersionResponseTypeDef,
    GetTableVersionsRequestRequestTypeDef,
    GetTableVersionsResponseTypeDef,
    GetTablesRequestRequestTypeDef,
    GetTablesResponseTypeDef,
    GetTagsRequestRequestTypeDef,
    GetTagsResponseTypeDef,
    GetTriggerRequestRequestTypeDef,
    GetTriggerResponseTypeDef,
    GetTriggersRequestRequestTypeDef,
    GetTriggersResponseTypeDef,
    GetUserDefinedFunctionRequestRequestTypeDef,
    GetUserDefinedFunctionResponseTypeDef,
    GetUserDefinedFunctionsRequestRequestTypeDef,
    GetUserDefinedFunctionsResponseTypeDef,
    GetWorkflowRequestRequestTypeDef,
    GetWorkflowResponseTypeDef,
    GetWorkflowRunPropertiesRequestRequestTypeDef,
    GetWorkflowRunPropertiesResponseTypeDef,
    GetWorkflowRunRequestRequestTypeDef,
    GetWorkflowRunResponseTypeDef,
    GetWorkflowRunsRequestRequestTypeDef,
    GetWorkflowRunsResponseTypeDef,
    GluePolicyTypeDef,
    GlueTableTypeDef,
    GrokClassifierTypeDef,
    ImportCatalogToGlueRequestRequestTypeDef,
    ImportLabelsTaskRunPropertiesTypeDef,
    JdbcTargetTypeDef,
    JobBookmarkEntryTypeDef,
    JobBookmarksEncryptionTypeDef,
    JobCommandTypeDef,
    JobNodeDetailsTypeDef,
    JobRunTypeDef,
    JobTypeDef,
    JobUpdateTypeDef,
    JsonClassifierTypeDef,
    KeySchemaElementTypeDef,
    LabelingSetGenerationTaskRunPropertiesTypeDef,
    LastActiveDefinitionTypeDef,
    LastCrawlInfoTypeDef,
    LineageConfigurationTypeDef,
    ListBlueprintsRequestRequestTypeDef,
    ListBlueprintsResponseTypeDef,
    ListCrawlersRequestRequestTypeDef,
    ListCrawlersResponseTypeDef,
    ListDevEndpointsRequestRequestTypeDef,
    ListDevEndpointsResponseTypeDef,
    ListJobsRequestRequestTypeDef,
    ListJobsResponseTypeDef,
    ListMLTransformsRequestRequestTypeDef,
    ListMLTransformsResponseTypeDef,
    ListRegistriesInputRequestTypeDef,
    ListRegistriesResponseTypeDef,
    ListSchemaVersionsInputRequestTypeDef,
    ListSchemaVersionsResponseTypeDef,
    ListSchemasInputRequestTypeDef,
    ListSchemasResponseTypeDef,
    ListTriggersRequestRequestTypeDef,
    ListTriggersResponseTypeDef,
    ListWorkflowsRequestRequestTypeDef,
    ListWorkflowsResponseTypeDef,
    LocationTypeDef,
    LongColumnStatisticsDataTypeDef,
    MLTransformTypeDef,
    MLUserDataEncryptionTypeDef,
    MappingEntryTypeDef,
    MetadataInfoTypeDef,
    MetadataKeyValuePairTypeDef,
    MongoDBTargetTypeDef,
    NodeTypeDef,
    NotificationPropertyTypeDef,
    OrderTypeDef,
    OtherMetadataValueListItemTypeDef,
    PaginatorConfigTypeDef,
    PartitionErrorTypeDef,
    PartitionIndexDescriptorTypeDef,
    PartitionIndexTypeDef,
    PartitionInputTypeDef,
    PartitionTypeDef,
    PartitionValueListTypeDef,
    PhysicalConnectionRequirementsTypeDef,
    PredecessorTypeDef,
    PredicateTypeDef,
    PrincipalPermissionsTypeDef,
    PropertyPredicateTypeDef,
    PutDataCatalogEncryptionSettingsRequestRequestTypeDef,
    PutResourcePolicyRequestRequestTypeDef,
    PutResourcePolicyResponseTypeDef,
    PutSchemaVersionMetadataInputRequestTypeDef,
    PutSchemaVersionMetadataResponseTypeDef,
    PutWorkflowRunPropertiesRequestRequestTypeDef,
    QuerySchemaVersionMetadataInputRequestTypeDef,
    QuerySchemaVersionMetadataResponseTypeDef,
    RecrawlPolicyTypeDef,
    RegisterSchemaVersionInputRequestTypeDef,
    RegisterSchemaVersionResponseTypeDef,
    RegistryIdTypeDef,
    RegistryListItemTypeDef,
    RemoveSchemaVersionMetadataInputRequestTypeDef,
    RemoveSchemaVersionMetadataResponseTypeDef,
    ResetJobBookmarkRequestRequestTypeDef,
    ResetJobBookmarkResponseTypeDef,
    ResourceUriTypeDef,
    ResponseMetadataTypeDef,
    ResumeWorkflowRunRequestRequestTypeDef,
    ResumeWorkflowRunResponseTypeDef,
    S3EncryptionTypeDef,
    S3TargetTypeDef,
    ScheduleTypeDef,
    SchemaChangePolicyTypeDef,
    SchemaColumnTypeDef,
    SchemaIdTypeDef,
    SchemaListItemTypeDef,
    SchemaReferenceTypeDef,
    SchemaVersionErrorItemTypeDef,
    SchemaVersionListItemTypeDef,
    SchemaVersionNumberTypeDef,
    SearchTablesRequestRequestTypeDef,
    SearchTablesResponseTypeDef,
    SecurityConfigurationTypeDef,
    SegmentTypeDef,
    SerDeInfoTypeDef,
    SkewedInfoTypeDef,
    SortCriterionTypeDef,
    StartBlueprintRunRequestRequestTypeDef,
    StartBlueprintRunResponseTypeDef,
    StartCrawlerRequestRequestTypeDef,
    StartCrawlerScheduleRequestRequestTypeDef,
    StartExportLabelsTaskRunRequestRequestTypeDef,
    StartExportLabelsTaskRunResponseTypeDef,
    StartImportLabelsTaskRunRequestRequestTypeDef,
    StartImportLabelsTaskRunResponseTypeDef,
    StartJobRunRequestRequestTypeDef,
    StartJobRunResponseTypeDef,
    StartMLEvaluationTaskRunRequestRequestTypeDef,
    StartMLEvaluationTaskRunResponseTypeDef,
    StartMLLabelingSetGenerationTaskRunRequestRequestTypeDef,
    StartMLLabelingSetGenerationTaskRunResponseTypeDef,
    StartTriggerRequestRequestTypeDef,
    StartTriggerResponseTypeDef,
    StartWorkflowRunRequestRequestTypeDef,
    StartWorkflowRunResponseTypeDef,
    StartingEventBatchConditionTypeDef,
    StopCrawlerRequestRequestTypeDef,
    StopCrawlerScheduleRequestRequestTypeDef,
    StopTriggerRequestRequestTypeDef,
    StopTriggerResponseTypeDef,
    StopWorkflowRunRequestRequestTypeDef,
    StorageDescriptorTypeDef,
    StringColumnStatisticsDataTypeDef,
    TableErrorTypeDef,
    TableIdentifierTypeDef,
    TableInputTypeDef,
    TableTypeDef,
    TableVersionErrorTypeDef,
    TableVersionTypeDef,
    TagResourceRequestRequestTypeDef,
    TaskRunFilterCriteriaTypeDef,
    TaskRunPropertiesTypeDef,
    TaskRunSortCriteriaTypeDef,
    TaskRunTypeDef,
    TransformEncryptionTypeDef,
    TransformFilterCriteriaTypeDef,
    TransformParametersTypeDef,
    TransformSortCriteriaTypeDef,
    TriggerNodeDetailsTypeDef,
    TriggerTypeDef,
    TriggerUpdateTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateBlueprintRequestRequestTypeDef,
    UpdateBlueprintResponseTypeDef,
    UpdateClassifierRequestRequestTypeDef,
    UpdateColumnStatisticsForPartitionRequestRequestTypeDef,
    UpdateColumnStatisticsForPartitionResponseTypeDef,
    UpdateColumnStatisticsForTableRequestRequestTypeDef,
    UpdateColumnStatisticsForTableResponseTypeDef,
    UpdateConnectionRequestRequestTypeDef,
    UpdateCrawlerRequestRequestTypeDef,
    UpdateCrawlerScheduleRequestRequestTypeDef,
    UpdateCsvClassifierRequestTypeDef,
    UpdateDatabaseRequestRequestTypeDef,
    UpdateDevEndpointRequestRequestTypeDef,
    UpdateGrokClassifierRequestTypeDef,
    UpdateJobRequestRequestTypeDef,
    UpdateJobResponseTypeDef,
    UpdateJsonClassifierRequestTypeDef,
    UpdateMLTransformRequestRequestTypeDef,
    UpdateMLTransformResponseTypeDef,
    UpdatePartitionRequestRequestTypeDef,
    UpdateRegistryInputRequestTypeDef,
    UpdateRegistryResponseTypeDef,
    UpdateSchemaInputRequestTypeDef,
    UpdateSchemaResponseTypeDef,
    UpdateTableRequestRequestTypeDef,
    UpdateTriggerRequestRequestTypeDef,
    UpdateTriggerResponseTypeDef,
    UpdateUserDefinedFunctionRequestRequestTypeDef,
    UpdateWorkflowRequestRequestTypeDef,
    UpdateWorkflowResponseTypeDef,
    UpdateXMLClassifierRequestTypeDef,
    UserDefinedFunctionInputTypeDef,
    UserDefinedFunctionTypeDef,
    WorkflowGraphTypeDef,
    WorkflowRunStatisticsTypeDef,
    WorkflowRunTypeDef,
    WorkflowTypeDef,
    XMLClassifierTypeDef,
)

def get_structure() -> ActionTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-glue` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-glue docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_glue/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
